@@ -1,5 +1,5 @@
 #!/bin/sh
-# @(#) $Id: updatetimestamps.sh 351 2024-12-28 21:03:34Z leres $ (XSE)
+# @(#) $Id: updatetimestamps.sh 363 2025-09-12 18:32:26Z leres $ (XSE)
 #
 # updatetimestamps - image the timestamps section of a webindex.conf file
 #
@@ -61,7 +61,7 @@ gentimestamps()
 	fi
 
 	ls ${d} |
-	sed -e 's/[\"\(\)\`\$]/\\&/g' -e "s/'/\\\'/g" | tee /tmp/x | awk '
+	sed -e 's/[\"\(\)\`\$]/\\&/g' -e "s/'/\\\'/g" | awk '
 	/\.(BMP|GIF|JPG|M4A|MOV|MP4|MPG|PDF|PNG|TIF|TXT|WMV|bmp|gif|jpg|m4a|mov|mp3|mp4|mp4|mpg|pdf|png|tif|txt|wmv)$/ {
 		files[$0] = 1
 		next
