@@ -1,5 +1,5 @@
 /*
- * @(#) $Id: webindex.c 361 2025-09-09 18:23:54Z leres $ (XSE)
+ * @(#) $Id: webindex.c 366 2025-09-14 21:11:59Z leres $ (XSE)
  *
  * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2013, 2015, 2016, 2017, 2018, 2019, 2022, 2023, 2025
  *	Craig Leres
@@ -555,6 +555,11 @@ process(const char *dname)
 	/* Sort names; we must do this before calling hookupthumbnails() */
 	sortwebfiles(cf, webfiles, nwebfiles);
 
+	/* Need timestamps to use auto day sections */
+	if ((cf->c_flags & C_DAY_SECTION) != 0 && cf->c_timestamps == NULL)
+		fprintf(stderr, "%s: warning: autodaysection is configured"
+		" but timestamps are not\n", prog);
+
 	/* If we have user configured thumbnails, hook them up */
 	hookupthumbnails(cf, webfiles, nwebfiles);
 
@@ -645,11 +650,15 @@ process(const char *dname)
 			continue;
 
 		/* New row logic */
-		tm = localtime(&wp->w_timestamp);
-		ymd = TM2YMD(tm);
-		autosection =
-		    ((cf->c_flags & C_DAY_SECTION) != 0 && ymd != lastymd);
-
+		autosection = 0;
+		ymd = 0;
+		if ((cf->c_flags & C_DAY_SECTION) != 0 &&
+		    wp->w_timestamp > 0 && !WEBFILE_ISDIR(wp)) {
+			tm = localtime(&wp->w_timestamp);
+			ymd = TM2YMD(tm);
+			if (ymd != lastymd)
+				autosection = 1;
+		}
 
 		section = findsection(wp, cf);
 		if (intable && (col >= cf->c_maxcol ||
@@ -1727,6 +1736,12 @@ websort_time(const void *a1, const void *a2)
 
 	w1 = a1;
 	w2 = a2;
+	/* Sort directories last when sorting by time */
+	if (!WEBFILE_ISDIR(w1) && WEBFILE_ISDIR(w2))
+		return (-1);
+	if (WEBFILE_ISDIR(w1) && !WEBFILE_ISDIR(w2))
+		return (1);
+
 	if (w1->w_timestamp == w2->w_timestamp)
 		return (websort_lex(a2, a1));
 	return (w1->w_timestamp - w2->w_timestamp);
@@ -1739,6 +1754,11 @@ websort_revtime(const void *a1, const void *a2)
 
 	w1 = a1;
 	w2 = a2;
+	/* Sort directories last when sorting by time */
+	if (!WEBFILE_ISDIR(w1) && WEBFILE_ISDIR(w2))
+		return (-1);
+	if (WEBFILE_ISDIR(w1) && !WEBFILE_ISDIR(w2))
+		return (1);
 	if (w1->w_timestamp == w2->w_timestamp)
 		return (websort_lex(a1, a2));
 	return (w2->w_timestamp - w1->w_timestamp);
